@@ -4,7 +4,7 @@
 - [ ] make plot_epochs even faster
 '''
 
-__all__ = ['torch','th','torchvision','T','transforms','nn','np','F','Dataset','DataLoader','optim','Report','Reshape','Permute','device']
+__all__ = ['torch','th','torchvision','T','nn','np','F','Dataset','DataLoader','optim','Report','Reshape','Permute']
 
 import torch, torchvision
 import torch as th
@@ -19,8 +19,6 @@ from collections import namedtuple, defaultdict
 import re
 from itertools import dropwhile, takewhile
 
-device = 'cuda' if torch.cuda.is_available() else 'cpu'
-
 class Reshape(nn.Module):
     def __init__(self, *shape):
         super().__init__()
@@ -35,7 +33,7 @@ class Permute(nn.Module):
         return x.permute(*self.order)
 
 metric = namedtuple('metric', 'pos,val'.split(','))
-info = lambda report, precision: '\t'.join([f'{k}: {v:.{precision}f}' for k,v in report.items()])
+info = lambda report: '\t'.join([f'{k}: {v:.3f}' for k,v in report.items()])
 
 def to_np(x):
     if isinstance(x, torch.Tensor): return x.detach().cpu().numpy()
@@ -43,10 +41,9 @@ def to_np(x):
         return x
 
 class Report:
-    def __init__(self, n_epochs, precision=3):
+    def __init__(self, n_epochs):
         self.start = time.time()
         self.n_epochs = n_epochs
-        self.precision = precision
         self.completed_epochs = -1
         self.logged = []
 
@@ -99,7 +96,7 @@ class Report:
         avgs = defaultdict(list)
         keys = self.logged if keys is None else keys
         from tqdm import trange
-        for epoch in trange(self.n_epochs+1):
+        for epoch in trange(self.n_epochs):
             for k in keys:
                 items = takewhile(lambda x: epoch-1<=x.pos<epoch,
                     dropwhile(lambda x: (epoch-1>x.pos or x.pos>epoch), getattr(self,k)))
@@ -148,46 +145,10 @@ class Report:
         elapsed = '\t({:.2f}s - {:.2f}s remaining)'.format(time.time() - self.start, ((self.n_epochs-pos)/pos)*elapsed)
         current_iteration = f'EPOCH: {pos:.3f}\t'
         if end == '\r':
-            print(f'\r{log}{current_iteration}{info(report, self.precision)}{elapsed}', end='')
+            print(f'\r{log}{current_iteration}{info(report)}{elapsed}', end='')
         else:
-            print(f'\r{log}{current_iteration}{info(report, self.precision)}{elapsed}', end=end)
+            print(f'\r{log}{current_iteration}{info(report)}{elapsed}', end=end)
 
-try:
-    from pytorch_lightning.callbacks.progress import ProgressBarBase
-    class LightningReport(ProgressBarBase):
-        def __init__(self, epochs, print_total=10, precision=4):
-            super().__init__()
-            self.enable = True
-            self.epoch_ix = 0
-            self.report = Report(epochs, precision)
-            self.print_every = epochs // print_total
-
-        def disable(self):
-            self.enable = False
-
-        def on_epoch_end(self, trainer, pl_module):
-            self.epoch_ix += 1
-            if self.epoch_ix % self.print_every == 0:
-                self.report.report_avgs(self.epoch_ix)
-
-        def on_train_batch_end(self, trainer, pl_module, outputs, batch, batch_idx, dataloader_idx):
-            super().on_train_batch_end(trainer, pl_module, outputs, batch, batch_idx, dataloader_idx)
-            loss = float(trainer.progress_bar_dict["loss"])
-            self.px = self.epoch_ix + ((1+batch_idx)/self.total_train_batches)
-            self.report.record(self.px, trn_loss=loss, end='\r')
-
-        def on_validation_batch_end(self, trainer, pl_module, outputs, batch, batch_idx, dataloader_idx):
-            super().on_train_batch_end(trainer, pl_module, outputs, batch, batch_idx, dataloader_idx)
-            loss = float(trainer.progress_bar_dict["loss"])
-            self.px = self.epoch_ix + ((1+batch_idx)/self.total_val_batches)
-            self.report.record(self.px, val_loss=loss, end='\r')
-
-        def __getattr__(self, attr, **kwargs):
-            return getattr(self.report, attr, **kwargs)
-
-    __all__ += ['LightningReport']
-except:
-    ...
 
 def moving_average(a, n=3) :
     b = np.zeros_like(a)
